@@ -47,7 +47,8 @@ class ITestInstaller(_Interface):
         :param observer:
             Observer object that makes it possible to monitor the actions
             performed by the test installer.
-        :type observer: :class:`~lava_test.api.observers.ITestInstallerObserver`
+        :type observer:
+            :class:`~lava_test.api.observers.ITestInstallerObserver`
 
         .. versionadded:: 0.2
         """
@@ -116,7 +117,8 @@ class ITestParser(_Interface):
         """
         Results dictionary to be merged with TestRun object inside the bundle.
 
-        .. seealso:: :meth:`~lava_test.core.artifacts.TestArtifacts.incorporate_parse_results`
+        .. seealso::
+            :meth:`~lava_test.core.artifacts.TestArtifacts.incorporate_parse_results`
 
         .. versionadded:: 0.1
         """
