@@ -14,14 +14,16 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-   This script automates the automate installation, execution, and
-   results parsing for the OpenPosix test suite.
-   The POSIX Test Suite is an open source test suite with the goal of
-   performing conformance, functional, and stress testing of the IEEE
-   1003.1-2001 System Interfaces specification However the automation here
-   does not support the stress test runs.
+The POSIX Test Suite is an open source test suite with the goal of
+performing conformance, functional, and stress testing of the IEEE
+1003.1-2001 System Interfaces specification However the automation here
+does not support the stress test runs.
 
+**URL:** http://sourceforge.net/projects/posixtest/
+
+**Default options:** None
 """
+
 import re
 
 from lava_test.core.installers import TestInstaller
@@ -30,28 +32,32 @@ from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
 
-VERSION="20100831"
-URL= "http://downloads.sourceforge.net/project/ltp/LTP Source/ltp-%s/"\
-     "ltp-full-%s.bz2" % (VERSION, VERSION)
-MD5="6982c72429a62f3917c13b2d529ad1ce"
+VERSION = "20100831"
+URL = ("http://downloads.sourceforge.net/project/ltp/LTP Source/ltp-%s/"
+      "ltp-full-%s.bz2") % (VERSION, VERSION)
+MD5 = "6982c72429a62f3917c13b2d529ad1ce"
 DEFAULT_OPTIONS = ""
 INSTALLSTEPS = ['tar -xjf ltp-full-20100831.bz2']
 DEPS = ['gcc', 'bzip2']
-RUNSTEPS = ['cd ltp-full-20100831/testcases/open_posix_testsuite/ && make $(OPTIONS)']
+RUNSTEPS = [
+    ('cd ltp-full-20100831/testcases/open_posix_testsuite/'
+     ' && make $(OPTIONS)')]
 
-PATTERN = "((?P<test_case_id>\A(\w+[/]+)+\w+[-]*\w*[-]*\w*) .*? (?P<result>\w+))"
+PATTERN = ("((?P<test_case_id>\A(\w+[/]+)+\w+[-]*\w*[-]*\w*)"
+           " .*? (?P<result>\w+))")
 FIXUPS = {
-            "FAILED"      :  "fail",
-            "INTERRUPTED" :  "skip",
-            "PASSED"      :  "pass",
-            "UNRESOLVED"  :  "unknown",
-            "UNSUPPORTED" :  "skip",
-            "UNTESTED"    :  "skip",
-            "SKIPPING"    :  "skip"
-         }
+    "FAILED": "fail",
+    "INTERRUPTED": "skip",
+    "PASSED": "pass",
+    "UNRESOLVED": "unknown",
+    "UNSUPPORTED": "skip",
+    "UNTESTED": "skip",
+    "SKIPPING": "skip"
+}
 
 
 class PosixParser(TestParser):
+
     def parse(self, artifacts):
         filename = "testoutput.log"
         pat = re.compile(self.pattern)
@@ -68,10 +74,14 @@ class PosixParser(TestParser):
                 self.results['test_results'].append(
                     self.analyze_test_result(results))
 
-posix_inst = TestInstaller(INSTALLSTEPS, deps=DEPS,
-    url=URL, md5=MD5)
-posix_run = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
-posixparser = PosixParser(PATTERN, fixupdict = FIXUPS)
-testobj = Test(test_id="posixtestsuite", test_version=VERSION,
-                                  installer=posix_inst, runner=posix_run,
-                                  parser=posixparser)
+
+installer = TestInstaller(INSTALLSTEPS, deps=DEPS, url=URL, md5=MD5)
+runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
+parser = PosixParser(PATTERN, fixupdict=FIXUPS)
+
+testobj = Test(
+    test_id="posixtestsuite",
+    test_version=VERSION,
+    installer=installer,
+    runner=runner,
+    parser=parser)
