@@ -21,8 +21,6 @@ Linaro Power Management QA test suite
 **Default options:** None
 """
 
-
-
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
@@ -33,7 +31,7 @@ DEFAULT_OPTIONS = ""
 INSTALLSTEPS = ['git clone git://git.linaro.org/tools/pm-qa.git',
                 'cd pm-qa && make clean && make all']
 RUNSTEPS = ['cd pm-qa && make check $(OPTIONS)']
-DEPS = ['git-core', 'make', 'linux-libc-dev', 'util-linux', 'build-essential']
+DEPS = ['git-core', 'linux-libc-dev', 'build-essential']
 
 # test case name is before  ":" , the test log is between ":" and "...",
 # the result is after "..."
@@ -56,7 +54,6 @@ PATTERN = (
     "\.\.\.\s+"
     "(?P<result>\w+)")
 
-
 installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parser = TestParser(PATTERN, appendall={'result': 'pass'})
