@@ -13,6 +13,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+Simple test for smem that simply reports the memory usage with shared memory divided proportionally
+
+**URL:** None
+
+**Default options:** None
+"""
+
+
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
@@ -23,10 +32,12 @@ RUNSTEPS = ['smem -w $(OPTIONS) | tail -n 3']
 PATTERN = "^(?P<test_case_id>(\w+\s)+)\s\s+(?P<measurement>\d+)"
 DEPS = ['smem']
 
+installer = TestInstaller(deps=DEPS)
+runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
+parser = TestParser(PATTERN, appendall={'units': 'KB', 'result': 'pass'})
 
-smeminst = TestInstaller(deps=DEPS)
-smemrun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
-smemparser = TestParser(PATTERN,
-               appendall={'units':'KB', 'result':'pass'})
-testobj = Test(test_id="smem", installer=smeminst,
-                                  runner=smemrun, parser=smemparser)
+testobj = Test(
+    test_id="smem",
+    installer=installer,
+    runner=runner,
+    parser=parser)
