@@ -15,10 +15,10 @@
 
 """
 xrestop - test for X11 server resource usage monitor
-^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-Default options:
- None
+**URL:** None
+
+**Default options:** None
 """
 
 from lava_test.core.installers import TestInstaller
@@ -31,9 +31,12 @@ RUNSTEPS = ["./xrestopscript/xrestop.sh $(OPTIONS)"]
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+)"
 DEFAULT_OPTIONS = ""
 
-xrestopinst = TestInstaller(INSTALLSTEPS, deps=["xrestop"])
-xrestoprun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
-xrestopparser = TestParser(PATTERN,
-                   appendall={'units':'KB', 'result':'pass'})
-testobj = Test(test_id="xrestop", installer=xrestopinst,
-                                  runner=xrestoprun, parser=xrestopparser)
+installer = TestInstaller(INSTALLSTEPS, deps=["xrestop"])
+runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
+parser = TestParser(PATTERN, appendall={'units': 'KB', 'result': 'pass'})
+
+testobj = Test(
+    test_id="xrestop",
+    installer=installer,
+    runner=runner,
+    parser=parser)
